==> vite_1.1.orig.tar.gz: vite-1.1/src/common/Tools.hpp <==
/*
** This file is part of the ViTE project.
**
** This software is governed by the CeCILL-A license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-A license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-A license and that you accept its terms.
**
**
** ViTE developers are (for version 0.* to 1.0):
**
**        - COULOMB Kevin
**        - FAVERGE Mathieu
**        - JAZEIX Johnny
**        - LAGRASSE Olivier
**        - MARCOUEILLE Jule
**        - NOISETTE Pascal
**        - REDONDY Arthur
**        - VUCHENER Clément 
**
*/
/*!
 *\file Tools.hpp
 *\brief This file contains functions that are used in different modules and do not belong to a particular class.
 */

#ifndef TOOLS_HPP
#define TOOLS_HPP

#include <string>

/*!
 * \fn convert_to_double(const std::string args)
 * \brief Convert the string in double
 * \param args the string to be doublized.
 * \return the double well converted or -1. on error.
 */
double convert_to_double(const std::string args);

#define MIN(x,y) (((x)<(y))?(x):(y))
#define MAX(x,y) (((x)<(y))?(y):(x))

/*!
 * \fn clockGet()
 * \brief Timing routine.
 *  Uses different timing routines depending on the machine architecture.
 * \return the time ellapsed since <clockStart>.
 */
double clockGet (void);

#endif // TOOLS_HPP

==> vite_1.2.orig.tar.gz: vite-1.2/src/common/Tools.hpp <==
/*
** This file is part of the ViTE project.
**
** This software is governed by the CeCILL-A license under French law
** and abiding by the rules of distribution of free software. You can
** use, modify and/or redistribute the software under the terms of the
** CeCILL-A license as circulated by CEA, CNRS and INRIA at the following
** URL: "http://www.cecill.info".
** 
** As a counterpart to the access to the source code and rights to copy,
** modify and redistribute granted by the license, users are provided
** only with a limited warranty and the software's author, the holder of
** the economic rights, and the successive licensors have only limited
** liability.
** 
** In this respect, the user's attention is drawn to the risks associated
** with loading, using, modifying and/or developing or reproducing the
** software by the user in light of its specific status of free software,
** that may mean that it is complicated to manipulate, and that also
** therefore means that it is reserved for developers and experienced
** professionals having in-depth computer knowledge. Users are therefore
** encouraged to load and test the software's suitability as regards
** their requirements in conditions enabling the security of their
** systems and/or data to be ensured and, more generally, to use and
** operate it in the same conditions as regards security.
** 
** The fact that you are presently reading this means that you have had
** knowledge of the CeCILL-A license and that you accept its terms.
**
**
** ViTE developers are (for version 0.* to 1.0):
**
**        - COULOMB Kevin
**        - FAVERGE Mathieu
**        - JAZEIX Johnny
**        - LAGRASSE Olivier
**        - MARCOUEILLE Jule
**        - NOISETTE Pascal
**        - REDONDY Arthur
**        - VUCHENER Clément 
**
*/
/*!
 *\file Tools.hpp
 *\brief This file contains functions that are used in different modules and do not belong to a particular class.
 */

#ifndef TOOLS_HPP
#define TOOLS_HPP

/*!
 * \fn convert_to_double(const std::string args)
 * \brief Convert the string in double
 * \param args the string to be doublized.
 * \return the double well converted or -1. on error.
 */
double convert_to_double(const std::string args);

// #define MIN(x,y) (((x)<(y))?(x):(y))
// #define MAX(x,y) (((x)<(y))?(y):(x))

/*!
  \fn clockGet(void)
  \brief Timing routine.
  Uses different timing routines depending on the machine architecture.
  \return Returns the time ellapsed since 'clockStart'.
 */
double clockGet (void);

#endif // TOOLS_HPP
